==> HostCMS.Free_6.7.tar.gz: modules/site/alias/i18n/ru.php <==
<?php
/**
 * Sites.
 *
 * @package HostCMS
 * @subpackage Site
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Домены',
	'markDeleted_success' => 'Информация о домене удалена',
	'markDeleted_error' => 'Ошибка удаления информации о домене',
	'setCurrent_success' => 'Текущий домен успешно указан',
	'setCurrent_error' => 'Ошибка указания текущего домена',
	'site_delete_domens_message' => 'Домены успешно удалены!',
	'server_error_respond_data' => 'Ошибка обработки данных.',
	'getKey_success' => 'Ключ успешно получен.',
	'constant_check_error' => 'Не обнаружено необходимых констант, заполните поля формы Сайты &#8594; Настройки &#8594; Регистрационные данные',
	'server_error_respond_0' => 'Неизвестная ошибка!',
	'server_error_respond_1' => 'Изменилась конфигурация сервера, получение ключа невозможно. Обратитесь к администратору.',
	'server_error_respond_2' => 'Не найден пользователь. Проверьте правильность указания логина в регистрационных данных в разделе Сайты.',
	'server_error_respond_3' => 'Не найден заказ. Вероятно заказ принадлежит другому пользователю. Проверьте правильность указания логина пользователя в регистрационных данных в разделе Сайты.',
	'server_error_respond_4' => 'Не обнаружена система HostCMS. Попробуйте еще раз запросить ключ. Обратите внимание &mdash; на основном домене текущего сайта должна быть доступна система управления <b>и выводиться сообщение о ненайденном лицензионном ключе</b>. Указание основного домена осуществляется в списке доменов.',
	'server_error_respond_5' => 'Неправильное имя домена.',
	'server_error_respond_6' => 'Запрещено получение ключей, обратитесь к администратору.',
	'server_error_respond_10' => 'Ошибка 10. Обратитесь в службу поддержки.',
	'site_show_domen_title' => 'Домены сайта "%s"',
	'site_link_domen_add' => 'Добавить',
	'site_link_domens' => 'Домен',
	'error_current_alias' => 'Внимание! Сайт должен иметь основной домен!',
	'site_link_site' => 'Сайт',
	'current' => '<acronym title="Основной домен используется во многих модулях системы и разделе администрирования. Используется при формировании прямых ссылок">Основной домен</acronym>',
	'name' => '<acronym title="Домен (без http://, например site.ru)">Домен (без http://)</acronym>',
	'id' => 'Идентификатор',
	'site_id' => 'Идентификатор сайта',
	'site_parameters' => 'Параметры',
	'site_link_site_name' => 'Сайт "%s"',
	'site_link_sites' => 'Сайты',
	'site_edit_domen_form_title' => 'Редактирование информации о домене',
	'site_add_domen_form_title' => 'Добавление информации о домене',
	'site_add_domen_success' => 'Информация о домене успешно добавлена!',
	'site_add_domen_error' => 'Информация о домене не добавлена!',
	'edit_success' => 'Домен успешно добавлен!',
	'edit_error' => 'Ошибка! Домен не добавлен!',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'redirect' => '<acronym title="Использовать 301 редирект на основной домен">Редирект</acronym>',
	'setRedirect_success' => 'Информация сохранена',
);

==> HostCMS.Free_7.0.tar.gz: modules/site/alias/i18n/ru.php <==
<?php

return array(
	'model_name' => 'Домены',
	'markDeleted_success' => 'Информация о домене удалена',
	'markDeleted_error' => 'Ошибка удаления информации о домене',
	'setCurrent_success' => 'Текущий домен успешно указан',
	'setCurrent_error' => 'Ошибка указания текущего домена',
	'site_delete_domens_message' => 'Домены успешно удалены!',
	'server_error_respond_data' => 'Ошибка обработки данных.',
	'getKey_success' => 'Ключ успешно получен!',
	'constant_check_error' => 'Не обнаружено необходимых констант, заполните поля формы Сайты &#8594; Настройки &#8594; Регистрационные данные',
	'server_error_respond_0' => 'Неизвестная ошибка!',
	'server_error_respond_1' => 'Изменилась конфигурация сервера, получение ключа невозможно. Обратитесь к администратору.',
	'server_error_respond_2' => 'Не найден пользователь. Проверьте правильность указания логина в регистрационных данных в разделе Сайты.',
	'server_error_respond_3' => 'Не найден заказ. Вероятно заказ принадлежит другому пользователю. Проверьте правильность указания логина пользователя в регистрационных данных в разделе Сайты.',
	'server_error_respond_4' => 'Не обнаружена система HostCMS. Попробуйте еще раз запросить ключ.
	<br />Обратите внимание &mdash; на основном домене текущего сайта должна быть доступна система управления <b>и выводиться сообщение о ненайденном лицензионном ключе</b>. Указание основного домена осуществляется в списке доменов.
	<br /><b>Если ваш сайт работает через HTTPS, то у сайта должна быть установлена опция HTTPS</b>.',
	'server_error_respond_5' => 'Неправильное имя домена.',
	'server_error_respond_6' => 'Запрещено получение ключей, обратитесь к администратору.',
	'server_error_respond_10' => 'Ошибка 10. Обратитесь в службу поддержки.',
	'site_show_domen_title' => 'Домены сайта "%s"',
	'site_link_domen_add' => 'Добавить',
	'site_link_domens' => 'Домен',
	'error_current_alias' => 'Внимание! Сайт должен иметь основной домен!',
	'site_link_site' => 'Сайт',
	'current' => '<acronym title="Основной домен используется во многих модулях системы и разделе администрирования. Используется при формировании прямых ссылок">Основной домен</acronym>',
	'name' => '<acronym title="Домен (без http://, например site.ru)">Домен (без http://)</acronym>',
	'id' => 'Идентификатор',
	'site_id' => 'Идентификатор сайта',
	'site_parameters' => 'Параметры',
	'site_link_site_name' => 'Сайт "%s"',
	'site_link_sites' => 'Сайты',
	'site_edit_domen_form_title' => 'Редактирование информации о домене "%s"',
	'site_add_domen_form_title' => 'Добавление информации о домене',
	'site_add_domen_success' => 'Информация о домене успешно добавлена!',
	'site_add_domen_error' => 'Информация о домене не добавлена!',
	'edit_success' => 'Домен успешно добавлен!',
	'edit_error' => 'Ошибка! Домен не добавлен!',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'redirect' => '<acronym title="Использовать 301 редирект на основной домен">Редирект</acronym>',
	'setRedirect_success' => 'Информация сохранена',
	'get_key' => 'Получить ключ',
	'select_site' => 'Сайт',
	'move_success' => 'Домен успешно перенесен!',
);
